# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging

from ubuntu_system_tests.helpers.power import RepowerdJob
from ubuntu_system_tests.helpers.sensors import SensorsBase

logger = logging.getLogger(__name__)

DELAY_MS = 10
LIGHT_SENSOR_RESOLUTION = 1
LIGHT_SENSOR_MAX = 1000
LIGHT_SENSOR_MIN = 0
LIGHT_SENSOR_MID = (LIGHT_SENSOR_MAX + LIGHT_SENSOR_MIN) // 2
ACCEL_SENSOR_RESOLUTION = 0.1
ACCEL_SENSOR_MAX = 1000
ACCEL_SENSOR_MIN = 0

repowerd_job = RepowerdJob()


class RepowerdSensors(SensorsBase):

    @staticmethod
    def get_fake_sensors_setup_commands():
        """Return list of commands required to configure the fake sensors."""
        cmds = ['create proximity',
                'create light {} {} {}'.format(
                    LIGHT_SENSOR_MIN, LIGHT_SENSOR_MAX,
                    LIGHT_SENSOR_RESOLUTION),
                '{} proximity far'.format(DELAY_MS),
                '{} light {}'.format(DELAY_MS, LIGHT_SENSOR_MID)]
        return cmds

    def _set_light_level(self, level, wait=1):
        """Set light sensor to specified value.
        :param wait: How long to wait in ms before applying value.
        """
        cmd = '{} light {}'.format(wait, level)
        self.write_to_fifo(repowerd_job.name, [cmd])

    def set_light_level_bright(self, wait=1):
        """Set light sensor to bright.
        :param wait: How long to wait in ms before applying value.
        """
        self._set_light_level(LIGHT_SENSOR_MAX, wait)

    def set_light_level_dark(self, wait=1):
        """Set light sensor to dark.
        :param wait: How long to wait in ms before applying value.
        """
        self._set_light_level(LIGHT_SENSOR_MIN, wait)

    def set_light_level_mid(self, wait=1):
        """Set light sensor to mid-range value.
        :param wait: How long to wait in ms before applying value.
        """
        self._set_light_level(LIGHT_SENSOR_MID, wait)

    def _set_proximity(self, value, wait=1):
        """Set proximity sensor to specified value.
        :param value: Either 'near' or 'far'.
        :param wait: How long to wait in ms before applying value.
        """
        cmd = '{} proximity {}'.format(wait, value)
        self.write_to_fifo(repowerd_job.name, [cmd])

    def set_proximity_near(self, wait=1):
        """Set proximity sensor to near.
        :param wait: How long to wait in ms before applying value.
        """
        self._set_proximity('near', wait)

    def set_proximity_far(self, wait=1):
        """Set proximity sensor to far.
        :param wait: How long to wait in ms before applying value.
        """
        self._set_proximity('far', wait)

    @staticmethod
    def is_brightness_sensor_present():
        # TODO: implement logic to query if brightness sensor
        # is present on the device
        return True

    @staticmethod
    def is_proximity_sensor_present():
        # TODO: implement logic to query if proximity sensor
        # is present on the device
        return True
