import fixtures

from ubuntu_system_tests.helpers import wait_until
from ubuntu_system_tests.helpers.init_systems import get_init_system

UBUNTU_PLATFORM_API_TEST_OVERRIDE = 'UBUNTU_PLATFORM_API_TEST_OVERRIDE'


class EnableFakeSensors(fixtures.Fixture):
    """Fixture to enable fake sensors."""

    def __init__(self, job, sensors):
        super().__init__()
        self.job = job
        self.init_system = get_init_system()
        self.sensors = sensors

    def setUp(self):
        super().setUp()
        if not self.are_fake_sensors_enabled():
            self.enable_fake_sensors()

        self.addCleanup(self.init_system.restart, self.job)

    def enable_fake_sensors(self):
        """Enable fake sensors on the job process."""
        self.init_system.ensure_stopped(self.job)
        args = ['UBUNTU_PLATFORM_API_TEST_OVERRIDE=sensors']
        self.init_system.start(self.job, *args)
        self.sensors.validate_fifo_ready(self.job.name)
        self.sensors.setup_sensors(self.job.name)
        wait_until(self.init_system.is_running, self.job)

    def are_fake_sensors_enabled(self):
        """Return True if fake sensors enabled."""
        try:
            pid = self.init_system.get_pid(self.job)
        except ValueError:
            return False
        return self.sensors.are_fake_sensors_enabled_for_process(pid)
