# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from ubuntu_system_tests.helpers.brightness._cpo import BrightnessPageBase
from ubuntu_system_tests.helpers.indicators._cpo import (IndicatorPage,
                                                         INDICATOR_PAGE_PATH)
from ubuntu_system_tests.helpers.autopilot import validate_dbus_object
from ubuntu_system_tests.helpers import unity8


class BatteryIndicatorPage(IndicatorPage, BrightnessPageBase):
    """Autopilot helper for the battery indicator page."""

    name = 'indicator-power'

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, unity8.UNITY8_PATH_ROOT, INDICATOR_PAGE_PATH,
            objectName='indicator-power-page')

    def _get_battery_settings_menu_item(self):
        """Return the battery settings list item."""
        return self.select_single(
            objectName='indicator.activate-phone-settings', visible=True)

    def open_battery_settings(self):
        """Tap the battery settings menu item to open settings."""
        self.pointing_device.click_object(
            self._get_battery_settings_menu_item())

    def get_auto_adjust_checkbox(self):
        """Return the auto brightness switch."""
        return self.select_single('SwitchMenu',
                                  objectName='indicator.auto-brightness')

    @staticmethod
    def get_max_brightness():
        return 1

    def enable_auto_brightness(self):
        """Enable auto brightness."""
        if not self.get_auto_adjust_status():
            self.toggle_auto_adjust()

    def disable_auto_brightness(self):
        """Disable auto brightness."""
        if self.get_auto_adjust_status():
            self.toggle_auto_adjust()

    def get_auto_adjust_status(self):
        """Return checked state of auto adjust switch."""
        return self._get_brightness_switch().checked

    def toggle_auto_adjust(self):
        """Press the auto adjust switch and wait for state to change."""
        brightness_switch = self._get_brightness_switch()
        original_state = brightness_switch.checked
        self.pointing_device.click_object(brightness_switch)
        brightness_switch.checked.wait_for(not original_state)
