# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntu_system_tests.helpers.application import QmlApplication
from ubuntu_system_tests.helpers import autopilot
from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers.scopes.apps import (
    launch_application_from_apps_scope
)
from ubuntu_system_tests.helpers.unity8 import (
    launch_application_from_launcher
)

APP = 'messaging-app'
APP_NAME = 'Messaging'
APP_ID = 'com.ubuntu.messaging'
APP_QML_FILE = 'messaging-app'
APP_CLICK = 'com.ubuntu.messaging'
APP_WIN_ID = 'messaging-app'


class Messaging(QmlApplication):

    def __init__(self):
        super().__init__(APP_NAME, APP_CLICK, APP_QML_FILE, APP_WIN_ID)

    def get_main_view(self):
        from ubuntu_system_tests.helpers.messaging import _cpo  # NOQA
        return self.get_proxy_object().main_view


def launch_messaging_app():
    """
    Launch the messaging app from apps scope and return proxy object.

    :return: Proxy object for messaging application.

    """
    launch_application_from_apps_scope(APP_NAME)
    return get_messaging_app_proxy()


def is_messaging_app_running():
    """ Indicate if the messaging app is currently running """
    return processes.is_process_running(APP)


def get_messaging_app_proxy(raw_proxy=False):
    """
    Return messaging app proxy object from existing process.

    :return: Proxy object for messaging application.

    """
    if raw_proxy:
        return autopilot.get_proxy_object(processes.get_process_id(APP),
                                          emulator_base=None)
    from ubuntu_system_tests.helpers.messaging._cpo import MainView
    proxy = autopilot.get_proxy_object(processes.get_process_id(APP))
    return autopilot.patched_wait_select_single(
        root=proxy, class_object=MainView, class_name='MainView')


def launch_messaging_app_from_launcher():
    """Drag out the launcher and tap the messaging app icon to start it."""
    launch_application_from_launcher(APP)
    return get_messaging_app_proxy()
