# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import subprocess

from ubuntu_system_tests.helpers import file_system as fs
from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers.music import (
    CONFIG_FILE,
    QML,
)

FIRST_RUN_CONFIG_TEXT = 'firstRun='


def get_current_song():
    return _get_current_url(fs.MUSIC_PREFIX)


def get_current_album():
    return _get_current_url(fs.ALBUM_PREFIX)


def _get_current_url(delimiter):
    """ Retrieve the current song based on the url parameter
    :param delimiter: The delimiter used to split the url args parameters
    """
    pid = processes.get_qmlscene_process_id(QML)
    line = processes.get_process_args(pid)
    args = line.split()
    for arg in args:
        if arg.startswith('--url='):
            return arg.split(delimiter)[1]
    return None


def set_welcome_wizard(enabled=True):
    """
    Enable/Disable first time wizard.
    :param enabled: Boolean representing if first run wizard should be enabled
    """
    replace_pattern = 's/{search}.*/{search}{value}/g'.format(
        search=FIRST_RUN_CONFIG_TEXT, value=str(enabled).lower())
    subprocess.check_call(['sed', '-i', replace_pattern, CONFIG_FILE])
