# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import logging
import subprocess

from fixtures import EnvironmentVariable as EV

from ubuntu_system_tests.helpers import processes
from ubuntu_system_tests.helpers import autopilot

APP_ID = 'online-accounts-ui'
SERVICE_ID = 'online-accounts-service'

logger = logging.getLogger(__name__)


def get_ubuntuone_credentials_proxy():
    """
    Return ubuntuone credentials proxy object from existing process.

    :return: Proxy object for ubuntuone credentials.

    """
    from ubuntu_system_tests.helpers.ubuntuone_credentials import _cpo  # NOQA
    return autopilot.get_proxy_object(processes.get_process_id(APP_ID))


def get_existing_account_ids():
    """Return a list of the ids of the existing accounts."""
    from unityclickscope.credentials import AccountManager
    accounts_manager = AccountManager()
    account_services = accounts_manager._manager.get_account_services()
    return [service.get_account().id for service in account_services]


def remove_accounts(ids_to_keep=None):
    """Remove the accounts that are logged in on the device.

    :param ids_to_keep: list of accounts that will not be removed.

    """
    from unityclickscope.credentials import AccountManager
    if ids_to_keep is None:
        ids_to_keep = []
    accounts_manager = AccountManager()
    account_services = accounts_manager._manager.get_account_services()
    for service in account_services:
        account = service.get_account()
        if account.id not in ids_to_keep:
            accounts_manager.delete_account(account)


def restart_online_services_with_testability():
    """Restart online services with testability enabled."""
    kill_online_service_process()
    launch_online_services_with_testability()


def launch_online_services_with_testability():
    """Launch online services process with testability enabled."""
    with EV('QT_LOAD_TESTABILITY', '1'), EV('OAU_DAEMON_TIMEOUT', '9999'):
        subprocess.Popen(
            [SERVICE_ID], stdout=subprocess.PIPE, stderr=subprocess.PIPE)


def kill_online_service_process():
    """Close online services process."""
    processes.stop_process(SERVICE_ID)
