# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
from threading import Event

from ubuntu_system_tests.helpers import ofono
from ubuntu_system_tests.helpers.init_systems import get_init_system
from ubuntu_system_tests.helpers.jobs import JobBase
from ubuntu_system_tests.helpers.notifications import sim_pin_observer
from ubuntu_system_tests.helpers.processes import is_process_running
from ubuntu_system_tests.helpers.unity8.sensors_utils import Unity8Sensors
from ubuntu_system_tests.helpers import context

from ubuntu_system_tests.helpers.unity8 import greeter


class Unity8Job(JobBase):

    def __init__(self):
        super().__init__('unity8')
        self.sensors = Unity8Sensors()
        self.init_system = get_init_system()

    def ensure_unity_running_and_greeter_hidden(self):
        if not is_process_running(self.name):
            self.init_system.start()
            greeter.wait_for_greeter()
        greeter.hide_greeter_with_dbus()

    def setup_fake_sensors(self):
        self.sensors.validate_fifo_ready(self.name)
        self.sensors.setup_sensors(self.name)

    @staticmethod
    def wait_for_unity_ready(dismiss_sim_unlock=True):
        """Wait until unity is ready, dismissing sim pin entry notifications
        if required.
        :param dismiss_sim_unlock: Whether to dismiss sim pin screens.
        """
        if dismiss_sim_unlock:
            locked_sims = ofono.get_locked_sims()
            if locked_sims:
                # There are locked sims, so dismiss any pin entry screens.
                # The pin entry screen does not always show, depending on
                # whether the sims have been unlocked previously after boot.
                # So clear the screens from a different thread to avoid
                # blocking here if they don't show.
                completed = Event()
                pin_observer = sim_pin_observer.start_sim_pin_observer(
                    completed, locked_sims)
                # Wait until there are no notifications and greeter displayed.
                n = context.shared.unity.main_window.get_notifications_list()
                n.count.wait_for(0)
                context.shared.unity.wait_for_greeter_content()
                if not completed.is_set():
                    # There were no sim pin screens shown, but greeter is now
                    # ready, so stop the sim pin observer.
                    pin_observer.stop()
            else:
                context.shared.unity.wait_for_greeter_content()
