# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
from testtools import skipUnless

from autopilot.matchers import Eventually
from testtools.matchers import Equals

from ubuntu_system_tests.helpers.addressbook import (
    AddressBook,
    get_test_contact,
)
from ubuntu_system_tests.tests import base
from ubuntu_system_tests.helpers.addressbook import (
    fixture_setup as addressbook_fixtures)

FIRST_NAME = 'Fulano'
LAST_NAME = 'de Tal'

TYPED_MOBILE = '818616313'
FORMATTED_MOBILE = '(818) 616-313'


class AddContactSystemTest(base.BaseUbuntuSystemTestCase):

    addressbook_app = AddressBook()

    @skipUnless(addressbook_app.is_installed(),
                'Address-book app required.')
    def setUp(self):
        super().setUp()
        self.useFixture(addressbook_fixtures.AddressBookTestEnvironment())

    def test_add_contact_with_name_and_number(self):
        self.addressbook_app.launch_from_scope(return_proxy=False)
        address_book = self.addressbook_app.get_main_view()

        test_contact = get_test_contact(FIRST_NAME, LAST_NAME, TYPED_MOBILE)
        test_contact_name = (
            test_contact.first_name + ' ' + test_contact.last_name)

        # Add new contact.
        contact_editor = address_book.go_to_add_contact()
        contact_editor.fill_form(test_contact)
        address_book.save()

        # Check that the contact was added.
        list_page = address_book.get_contact_list_page()
        contacts = list_page.get_contacts()
        self.assertIn(test_contact_name, contacts)

        # Check the contact details.
        contact_index = contacts.index(test_contact_name)
        list_page.expand_contact(contact_index)

        # Check the mobile number in the contact view page is ok
        view_page = address_book.get_contact_view_page()
        number = view_page.get_contact_mobile_phone_number()
        self.assertEqual(number, FORMATTED_MOBILE)

    def _assert_contact_in_contacts_list(self, name, number):
        """Ensure the newly saved contact is saved successfully."""
        contact_view_page = self.dialer_app.contacts_page.open_contact(0)
        self.assertThat(
            contact_view_page.get_title(), Eventually(Equals(name)))
        self.assertEquals(
            number,
            contact_view_page.get_contact_primary_number(),
        )
