# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2016 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; version 3.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

from autopilot import get_test_configuration
from autopilot.matchers import Eventually
from testtools.matchers import Equals

from ubuntu_system_tests.helpers import dekko
from ubuntu_system_tests.helpers.data import load_test_metadata
from ubuntu_system_tests.helpers.dekko import fixture_setup as dekko_fixture
from ubuntu_system_tests.tests import base

email_data = load_test_metadata().email


class EmailSetupTestCase(base.BaseUbuntuSystemTestCase):

    def setUp(self):
        super().setUp()
        self.useFixture(dekko_fixture.DekkoEnvironmentFixture())
        self.dekko = dekko.launch_dekko()
        self.assertThat(
            self.dekko.no_accounts_page.visible, Eventually(Equals(True)))
        self.config = get_test_configuration()

    def _add_new_email_account(self, email_provider):
        accounts_list = self.dekko.no_accounts_page.add_new_account()
        return accounts_list.add_email_account(name=email_provider)

    def _add_basic_authentication_email_account(
            self, provider_name, address, password):
        login_page = self._add_new_email_account(email_provider=provider_name)
        identity_page = login_page.login(email=address, password=password)
        self.assertIsNotNone(identity_page, 'email or password invalid')
        details_page = identity_page.go_to_details_page()
        details_page.finish_wizard()

    def test_add_yahoo_email_account(self):
        """
        1. Launch dekko and add a new account
        2. Select yahoo account
        3. Enter credentials and complete the wizard
        4. Ensure login is successful
        """
        self._add_basic_authentication_email_account(
            'yahoo', self.config.get('email_yahoo'),
            self.config.get('password_yahoo'))

    def test_add_outlook_email_account(self):
        """
        1. Launch dekko and add a new account
        2. Select outlook account
        3. Enter credentials and complete the wizard
        4. Ensure login is successful
        """
        self._add_basic_authentication_email_account(
            'outlook', self.config.get('email_outlook'),
            self.config.get('password_outlook'))

    def test_add_imap_account(self):
        """
        1. Launch dekko and add a new account
        2. Select IMAP account
        3. Enter credentials and complete the wizard
        4. Ensure login is successful
        """
        login_page = self._add_new_email_account(email_provider='imap')
        server_details_page = login_page.login_imap(
            username=self.config.get('username_imap'),
            password=self.config.get('password_imap'))
        account_details_page = server_details_page.enter_imap_server_details(
            host=email_data.imap_server_details.hostname,
            port=email_data.imap_server_details.port,
            encryption=email_data.imap_server_details.encryption)
        self.assertIsNotNone(
            account_details_page, message='username or password invalid')
        account_details_page.finish_wizard()
