from unittest import skipUnless

from autopilot import get_test_configuration

from ubuntu_system_tests.helpers.telegram.app import Telegram
from ubuntu_system_tests.tests import base
from ubuntu_system_tests.helpers import ofono
from ubuntu_system_tests.helpers.ofono import fixture_setup as ofono_fixture
from ubuntu_system_tests.helpers.telegram import (
    fixture_setup as telegram_fixture)

FIRST_NAME = 'Ubuntu'
LAST_NAME = 'QA'
FIVE_MINUTES = 300
SIM_INDEX = 0


class SetupTelegramTestCase(base.BaseUbuntuSystemTestCase):

    @skipUnless(
        ofono.is_sim_inserted(sim_number=SIM_INDEX),
        'No SIM inserted in slot {}'.format(SIM_INDEX + 1))
    def setUp(self):
        super().setUp()
        self.useFixture(telegram_fixture.BackupRestoreTelegramData())
        self.useFixture(ofono_fixture.UnlockSims())
        self.assertTrue(ofono.wait_for_sim_registered(sim=SIM_INDEX))

        self.telegram_app = Telegram()
        self.telegram_app.launch_from_scope(return_proxy=False)
        self.telegram = self.telegram_app.get_main_view()

        self.config = get_test_configuration()

    def _get_verification_code(self):
        """
        Wait for the telegram notification to appear and strip out verification
        code from it.
        """
        notifications_list = self.shell.get_notifications_list()
        notification = notifications_list.get_new_message_notification(
            FIVE_MINUTES)
        return notification.body.split()[-1]

    def test_sign_in(self):
        """
        1. Open telegram and tap 'Start Messaging'
        2. Select country the SIM is located in
        3. Enter SIM number to request pin code message
        4. When the message arrives, enter that code into the verification
           field. Fill other fields, if required.
        5. Proceed the wizard and ensure main telegram screen is visible
        """
        countries_list = self.telegram.intro_page.go_to_countries_list()
        phone_number_page = countries_list.select_country(
            name=self.config.get('country_sim'))
        verification_page = phone_number_page.send_phone_number(
            number=self.config.get('device_phone_number'),
            timeout=FIVE_MINUTES)
        verification_code = self._get_verification_code()
        verification_page.sign_in_or_signup(
            code=verification_code, first_name=FIRST_NAME, last_name=LAST_NAME,
            timeout=FIVE_MINUTES)
