# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import os

from autopilot.matchers import Eventually
from testtools.matchers import Equals

from ubuntu_system_tests.tests import base
from ubuntu_system_tests.helpers import click
from ubuntu_system_tests.helpers.data import load_test_metadata
from ubuntu_system_tests.helpers import file_system as fs
from ubuntu_system_tests.helpers.scopes import go_to_apps_scope

test_data = load_test_metadata()


class UninstallApplicationTestCase(base.BaseUbuntuSystemTestCase):

    def test_uninstall_application(self):
        click_file_path = os.path.join(
            fs.DIR_TEST_DATA_APPS, test_data.apps.click.file)
        self.useFixture(click.ClickPackageInstalled(click_file_path))
        apps_scope = go_to_apps_scope()
        apps_scope.refresh()
        preview = apps_scope.open_preview(
            'local', test_data.apps.click.name, press_duration=3)

        self.assertTrue(apps_scope.subPageShown)
        self.assertThat(
            preview.get_button_labels,
            Eventually(Equals(['Uninstall', 'Open'])))

        preview.uninstall()

        apps_scope.subPageShown.wait_for(False)
        apps_scope.swipe_to_top()
        self.assertNotIn(
            test_data.apps.click.name, apps_scope.get_applications('local'))
