# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
from autopilot.matchers import Eventually
from testtools import skipUnless
from testtools.matchers import Equals

from ubuntu_system_tests.helpers.dialer_app.app import Dialer
from ubuntu_system_tests.helpers.unity8 import (
    lock_unity,
    unlock_unity,
)
from ubuntu_system_tests.tests import base

FIRST_NAME = 'Fulano'
LAST_NAME = 'de Tal'

TYPED_MOBILE = '818616313'
FORMATTED_MOBILE = '(818) 616-313'


class TestWithDialerTestCase(base.BaseUbuntuSystemTestCase):

    dialer = Dialer()

    @skipUnless(dialer.is_installed(),
                'Dialer app required.')
    def setUp(self):
        super().setUp()
        self.dialer.launch_from_scope(return_proxy=False)
        self.dialer_app = self.dialer.get_main_view()

    def test_dialer_contacts_view_kept_on_screen_lock(self):
        """
        1. Open Dialer app and go to contacts list
        2. Lock the screen
        3. Unlock the screen
        4. Ensure contacts list is still visible
        """
        self.dialer_app.dialer_page.click_contacts_button()
        self.assertThat(self.dialer_app.contacts_page.active,
                        Eventually(Equals(True)))

        lock_unity()
        unlock_unity()

        self.assertThat(self.dialer_app.contacts_page.active,
                        Eventually(Equals(True)))

    def test_add_contact_from_dialer(self):
        """
        1. Dial a number
        2. Tap add to contact button
        3. Create a new contact with pre-filled number
        4. Ensure the newly saved contact is shown in the contacts list
        """
        contact_name = '{} {}'.format(FIRST_NAME, LAST_NAME)
        self.dialer_app.dialer_page.dial_number_add_new_contact(
            TYPED_MOBILE, FORMATTED_MOBILE)
        self.dialer_app.contacts_page.click_add_new()
        self.dialer_app.contacts_edit_page.create_new_contact(
            FIRST_NAME, LAST_NAME)
        self._assert_contact_in_contacts_list(contact_name, FORMATTED_MOBILE)

    def _assert_contact_in_contacts_list(self, name, number):
        """Ensure the newly saved contact is saved successfully."""
        contact_view_page = self.dialer_app.contacts_page.open_contact(0)
        self.assertThat(
            contact_view_page.get_title(), Eventually(Equals(name)))
        self.assertEquals(
            number,
            contact_view_page.get_contact_primary_number(),
        )
